@@ -119,10 +119,10 @@ class EditSuggestion(object):
         )
 
     def set_tracked_fields(self, copied_fields):
-        self.tracked_fields['m2m'] = [f['name'] for f in self.m2m_fields]
+        self.tracked_fields['m2m'] = [f for f in self.m2m_fields]
         for field_name in copied_fields.keys():
             # exclude id and m2m fields
-            if field_name == 'id' or field_name in self.tracked_fields['m2m']:
+            if field_name == 'id' or field_name in [f['name'] for f in self.tracked_fields['m2m']]:
                 continue
             self.tracked_fields['simple'].append(field_name)
 
@@ -248,8 +248,8 @@ class EditSuggestion(object):
                 setattr(instance.edit_suggestion_parent, updatable_field, getattr(instance, updatable_field))
             # set m2m fields
             for m2m_field in self.tracked_fields['m2m']:
-                parent_m2m_field = getattr(instance.edit_suggestion_parent, m2m_field)
-                instance_m2m_field = getattr(instance, m2m_field)
+                parent_m2m_field = getattr(instance.edit_suggestion_parent, m2m_field['name'])
+                instance_m2m_field = getattr(instance, m2m_field['name'])
                 parent_m2m_field.set(instance_m2m_field.all())
             instance.edit_suggestion_parent.save()
             instance.edit_suggestion_status = self.Status.PUBLISHED
@@ -259,7 +259,7 @@ class EditSuggestion(object):
             if not self.change_status_condition(instance, user):
                 raise PermissionDenied('User not allowed to reject the edit suggestion')
             instance.edit_suggestion_status = self.Status.REJECTED
-            instance.reject_reason = reason
+            instance.edit_suggestion_reject_reason = reason
             instance.save()
 
         extra_fields = {
@@ -352,7 +352,7 @@ class EditSuggestionChanges(object):
         changed_fields = []
         old_values = model_to_dict(self.edit_suggestion_parent)
         current_values = model_to_dict(self)
-        for field in self.edit_suggestion_tracked_fields['simple'] + self.edit_suggestion_tracked_fields['m2m']:
+        for field in self.edit_suggestion_tracked_fields['simple'] + [f['name'] for f in self.edit_suggestion_tracked_fields['m2m']]:
             if field in old_values and old_values[field] != current_values[field]:
                 change = ModelChange(field, old_values[field], current_values[field])
                 changes.append(change)
